function comp_con

% COMP_CON Show the help for the functions in this toolbox.

% This file is automatically generated.  Matthew Simoneau, 09-04-98
% Copyright (c) 1984-98 by The MathWorks, Inc. All Rights Reserved
% $Revision: 1.9 $ $Date: 1999/01/15 22:20:13 $

helpwin('comp_con/Contents');

function Contents
%MATLAB Tour Partial Function Help:  comp_con
%
%Double click on any function for more information
%
%  MATLAB Compiler (and Compiler 1.2.1)
%  Version 2.0 (R11) 08-Dec-1998
% 
%  Release Information.
%    Readme        - Display information about version 2.0 and 1.2.1.
% 
%  Compiler.
%    mcc           - MATLAB Compiler driver.
%    mccexec       - Actual M to C Compiler mex file.
%    mbuild        - Build MEX, C-file or stand-alone application.
% 
%  Assertions.
%    mbint         - Must be integer.
%    mbreal        - Must be real.
%    mbchar        - Must be character.
%    mbscalar      - Must be scalar.
%    mbvector      - Must be vector.
%    mbintscalar   - Must be integer scalar.
%    mbintvector   - Must be integer vector.
%    mbrealscalar  - Must be real scalar.
%    mbrealvector  - Must be real vector.
%    mbcharvector  - Must be character vector (MATLAB string).
%    mbcharscalar  - Must be character scalar.
% 
%  Real functions.
%    reallog       - Real logarithm.
%    realpow       - Real power.
%    realsqrt      - Real square root.
% 
%  Pragmas.
%    inbounds      - Subscripts in array bounds.
%    realonly      - Real only.
%    ivdep         - Ignore vector dependencies.
%    function      - Used in stand-alone mode to identify functions called 
%                    through feval()
%

function Readme
%MATLAB Tour Partial Function Help:  comp_con
%
%  Release Notes, MATLAB Compiler
%  Version 2.0 (R11) 22-Dec-1998
%  Copyright (c) 1984-1998 by The MathWorks, Inc.
% 
%  Compiler 2.0 / 1.2.1 INFORMATION
% 
%  This release contains a major upgrade to the MATLAB Compiler family.
%  Version 2.0 of the Compiler supports most of the MATLAB version 5 
%  language features (see below for details.)  It also includes 
%  Version 1.2.1 which is a patch release designed to fix defects 
%  reported against version 1.2 of the Compiler.  We have included both 
%  versions because Compiler 2.0 does not include all of the same 
%  optimization capabilities as the prior version of the Matlab Compiler.
%  Compiler 2.0 should be used for M files which use Matlab version 
%  5 langauage features, and the version 1.2.1 compiler should be used with
%  M-files which use the Matlab version 4.2 language features when peak 
%  performance is desired. 
% 
%  With this release there are numerous changes to the available command 
%  line options.  In order to assist in migrating to this new release, 
%  we have prepared a quick-reference card which contains both the 
%  Compiler 1.2.1 and the Compiler 2.0 options.  See the "Documentation" 
%  section at the end of this file for details on how to print this card.
% 
%  Important note to Compiler 1.2 customers: version 2.0 of the Compiler 
%  is the command line default from inside MATLAB and from the DOS/UNIX 
%  shell.  You will need to change your build procedures in order to use
%  the new Compiler.  If you do not wish to update your build procedures,
%  please see the section "Making Compiler 1.2.1 The Default Compiler"
%  below on how to make Compiler 1.2.1 the default Compiler.  
%  
%  Read the information below for details on what is new or
%  different about the V2.0/V1.2.1 Compilers.  For the latest 
%  information on the MATLAB C/C++ Math Library, see the 
%  MATLABROOT/extern/examples/cmath/release.txt and
%  MATLABROOT/extern/examples/cppmath/release.txt files, respectively.
% 
%  MATLABROOT above corresponds to the directory where MATLAB is 
%  installed on your system.
% 
%  Installation & Configuration of the MATLAB Compiler V2.0/V1.2.1
%  
%  Based on customer feedback, we have modified the installation and
%  configuration process for the MATLAB Compiler, to make it easier to 
%  install and configure. The Compiler User's Guide includes a complete 
%  set of recommended steps to perform during installation to ensure that 
%  everything is working properly. It includes troubleshooting sections 
%  to help diagnose and correct some of the more common installation 
%  problems.
%  
%  NOTE for Windows 95/98/NT customers: In this release of the Compiler, the 
%  following list of platform compiler vendors and product releases are
%  supported "out-of-the-box":
% 
%        WATCOM 10.6 and 11.0
%        Borland 5.0, 5.02, and 5.3
%        MSVC 4.2, 5.0, and 6.0(*)
% 
%  (*) When installing MSVC 6.0, if you need to change where this compiler is 
%      installed, you must change the location of the Common directory (at the 
%      appropriate installer dialog.) If you change the location of the VC98 
%      directory from its default setting, the MEX and MBUILD scripts will not
%      work properly. 
% 
%  Compiler V2.0 Specific Information
% 
%  The V2.0 Compiler supports the following MATLAB 5 language features:
% 
%      * Multi-dimensional Arrays
%      * Structures
%      * Cell Arrays
%      * Sparse Arrays
%      * varargin/varargout
%      * SWITCH/CASE
%      * TRY/CATCH
%      * EVALIN (MEX mode only)
%      * PERSISTENT
% 
%   Unsupported MATLAB 5 features in this version of the Compiler are:
% 
%      * User-defined classes (Matlab Objects)
%      * MATLAB 5 integer types (int8,16,32 and uint8,16,32)
% 
%  The V2.0 version of the Compiler does not perform the same optimizations that 
%  V1.2.1 does and some code may run slower when compiled with this version.  
%  In all cases, the code should run at least as fast as the equivalent 
%  interpreted M-code.  For this reason, you may want to continue to use the 
%  Compiler 1.2.1 if it provides better performance for your code.  
% 
%  Our #1 priority moving forward is to provide the full optimization levels that
%  our customers require.  We understand that the performance of M code is a concern
%  for all of our users.  In order to help us better understand your requirements,
%  we invite you to complete the Compiler survey (type help COMPILER_SURVEY for details.)
%  The survey GUI that comes up will compare the performance of the interpreted M code
%  and the C and C++ Compiler-generated code from Compiler 1.2 and Compiler 2.0.
%  At the end of the survey, you will be asked to provide the M code to us so that
%  we can examine it to determine how to make your M code execute faster.  We will use this
%  provided M code only for this purpose.
% 
%  If you experience a problem when using the MATLAB Compiler, please fill out a bug report
%  so that we can examine and fix the problem.  (Type help COMPILER_BUG_REPORT for details.)
% 
%  The options for the V2.0 Compiler are different than in prior versions; use
%  "mcc -?" for help on the new options.
% 
%  Version 2.0 of the Compiler is also available from the DOS/UNIX command line
%  (in addition to being available from within MATLAB.)  Type "mcc -?" for 
%  details on using the DOS/UNIX version of the Compiler.  This should make 
%  it considerably easier to write makefiles that control the building
%  of applications and MEX-files.
% 
%  Exception Handling and the Compiler-Generated C++ Code
% 
%  When using C++, we rely on the availability of exception handling in the
%  C++ language.  Several of the compilers that we support do not properly 
%  support C++ exception handling, and as a result our support for exception
%  handling is limited on those platforms, namely:
% 
%        GNU C++ 2.7.2             - Does not support C++ exception handling
%        Borland C++(all versions) - Has a restriction on support of goto 
%                                    statements within try/catch blocks.  The 
%                                    MATLAB Compiler sometimes generates goto 
%                                    statements for complicated "if" conditional 
%                                    statements.  The generated code for these 
%                                    will not compile in Borland C++, as a result
%                                    you will be required to simplify the if condition.
%        Watcom C++ (all versions) - When throwing an exception, the try/catch
%                                    run-time will occasionally produce 
%                                    unexpected results.  We are pursuing this 
%                                    issue with the vendor and characterizing 
%                                    the conditions under which this occurs.  
% 
%  NOTE: The -A debugline switch is implemented using try/catch statements,
%        use of this switch is also restricted in the above C++ 
%        implementations for the same reasons.
% 
%  Compiler V1.2.1 Specific Information
% 
%  The V1.2.1 Compiler supports the following MATLAB 5 language features:
% 
%     * Local functions
%     * The END built-in array indexing operator (as in x(1:end))
%     * Logical indexing
%     * Short-circuit conditional evaluation for IF/WHILE statements
% 
%  NOTE: Any feature not specifically mentioned in the above list is NOT 
%  supported by the V1.2.1 version of the MATLAB Compiler.  Specifically 
%  unsupported in V1.2.1 are:
% 
%      * Cell Arrays
%      * Multi-dimensional Arrays
%      * Structures
%      * User-defined classes (Matlab Objects)
%      * varargin/varargout
%      * SWITCH/CASE
%      * TRY/CATCH
% 
%  The options and switches to Compiler 1.2.1 are significantly different 
%  from those available for Compiler 2.0.  To obtain help for the Compiler 
%  1.2.1 options, use "mcc -V1.2 -?".
% 
%  All of the other 1.1 Compiler restrictions remain in effect for 1.2.1.  See the
%  documentation for a complete list.
% 
%  Making Compiler 1.2.1 The Default Compiler
% 
%  You can use the mccstartup feature (new to this release) to make Compiler
%  1.2.1 the default Compiler. An mccstartup file is a file containing MCC
%  command line options which are automatically processed any time MCC is
%  invoked. To configure an mccstartup file for changing the default Compiler,
%  create a text file named "mccstartup" and place the text "-V1.2" in that
%  file. (You can also put any other commonly used MCC command line options in
%  the file as well.) On UNIX, put this file in your $HOME/matlab directory
%  (create the directory if it doesn't already exist). On Windows, put this
%  file in the <MATLAB>\bin directory, where <MATLAB> is your root MATLAB
%  directory. MCC will now always treat "-V1.2" as the first command line
%  option it processes. Any options appearing in the mccstartup file behave
%  as if they appeared before the arguments specified on the command line.
%  If the Compiler sees conflicting options, the rightmost option is taken
%  For example, if you place "-V1.2" into your mccstartup file and then
%  invoke the Compiler with "mcc -V2.0" it behaves as if you had typed
%  "mcc -V1.2 -V2.0" and uses the V2.0 Compiler because it was specified
%  last.
% 
%  Documentation
% 
%  MATLAB Compiler V2.0
%  The "MATLAB Compiler V2.0 User's Guide" fully describes version 2.0 of
%  the Compiler. This manual is provided in print form as well as pdf format.
%  To access the pdf version, use the online Help Desk and select "Online
%  Manuals." The Compiler reference pages are included in the printed manual,
%  and they can also be accessed from the Help Desk by selecting "MATLAB
%  Compiler Reference" from "Other Products." There is also a Quick Reference
%  Card for the MATLAB Compiler that you can access from "Online Manuals" and
%  print at your convenience.
%  
%  MATLAB Compiler V1.2
%  The "MATLAB Compiler V1.2 User's Guide" is available in pdf format from the
%  online Help Desk. Note that the printed "MATLAB Compiler V2.0 User's Guide"
%  contains an Appendix with much of the relevant information from the
%  original "MATLAB Compiler V1.2 User's Guide".
% 

function mcc
%MATLAB Tour Partial Function Help:  comp_con
%
% MCC MATLAB to C/C++ Compiler (Version 2.0).
%    MCC [-options] fun [fun2 ... ]
%    
%    Translate fun.m to fun.c or fun.cpp, and optionally create any supported binary
%    file.  Write any resulting files into the current directory, by default.
%    
%    If more than one M-file is specified, a C or C++ file is generated for each
%    M-file.
%    
%    If C files are specified, they are passed to MEX or MBUILD along with any
%    generated C files.
%    
%    If conflicting options are presented to MCC, the rightmost conflicting option is
%    used.
%    
%    NOTE to Compiler 1.2 users: The options for Compiler 2.0 are somewhat different
%    from Compiler 1.2.  Type "mcc -V1.2 -?" to obtain the online help for
%    Compiler 1.2.
%    
%    In order to assist in migrating to this new release, we have prepared a
%    quick-reference card which contains both the Compiler 1.2.1 and the Compiler 2.0
%    options.  You can access this pdf file by selecting "Online Manuals" from the
%    HELPDESK.
%    
%    OPTIONS:
%    
%    A <keyword>:<setting> Specify annotation.  <keyword> can be one of "annotation",
%        "line", or "debugline".  "annotation" specifies how much of the source
%        M-file the Compiler should write into the generated output file as comments.
%        The <setting> following "annotation" can be "all" (default), "comments", or
%        "none", specifying all M-code, only M-code comments, and no M-code
%        respectively.  "line" specifies the presence or absence of #line directives
%        which map lines in a generated C/C++ file to corresponding lines in the
%        source M-file. The <setting> following "line" can be "off" (default), or
%        "on", specifying absence or presence of #line directives. "debugline"
%        specifies whether error messages report the source file name and line
%        number.  The <setting> following "debugline" can be "off" (default), or
%        "on", specifying the absence or presence of source file and line number
%        information in run-time error messages.
%    
%    B <filename> Specify bundle file.  <filename> is a text file containing Compiler
%        command line options.  The Compiler behaves as if the "-B <filename>" were
%        replaced by the contents of the bundle file. Newlines appearing in these
%        files are allowed and are treated as whitespace.
%    
%    c   C only.  Translate M-file to C, but do not produce a MEX-file or stand-alone
%        application.  This is equivalent to "-T codegen" as the rightmost argument
%        on the command line.
%    
%    d <directory> Output directory.  All generated files will be put in <directory>.
%    
%    F list.  List the <option>s available in the next form of the command, together
%        with their current values and a short explanation.
%    
%    F <option>:<number> Typesetting format options.  Assign the value <number> to
%        the formatting option <option>.  See "F list" for <option>s.
%    
%    f <filename> Use the specified options file when calling MEX or MBUILD.  This
%        allows you to use different ANSI compilers.  This option is a direct
%        pass-through to the MEX or MBUILD script.  See the "Application Program
%        Interface Guide" for more information.
%    
%    g   Debug.  Include debugging symbol information.
%    
%    h Compile helper functions by default.  Any M-functions called will be compiled
%        into the resulting MEX-file or stand-alone application.
%    
%    I <path> Include path.  Add <path> to the list of paths to search for M-files.
%        The MATLAB path is automatically included when running from MATLAB, but NOT
%        when running from DOS or the Unix shell.  See "help mccsavepath".
%    
%    L <option> Language.  Specifies target language.  <option> can be either
%        "C" for C or "Cpp" for C++.
%    
%    l   Line.  Generates code that reports file name and line numbers on run-time
%        errors.  (Equivalent to -A debugline:on)
%    
%    m   Macro that generates a C stand-alone application.  This is equivalent to
%        "-t -W main -L C -h -T link:exe".  Note:  the "-h" means that helper
%        functions will be included.
%    
%    M "<string>" Pass <string> to the MBUILD or MEX script used to build an
%        executable. If -M is used multiple times, the rightmost occurrence is used.
%    
%    o <outputfilename> Output name.  Set the name of the final executable output
%        (MEX or stand-alone application) to <outputfilename>.  A suitable, possibly
%        platform-dependent, extension is added to <outputfilename> (e.g., ".exe" for
%        PC stand-alone applications, ".mexsol" for Solaris MEX-files).
%    
%    p   Macro that generates C++ stand-alone application.  This is equivalent to
%        "-t -W main -L Cpp -h -T link:exe".  Note:  the "-h" means that helper
%        functions will be included.
%    
%    S   Macro that generates Simulink C-MEX S-Function.  This is equivalent to
%        "-t -W simulink -L C -T link:mex".  Note:  the absence of "-h" means that
%        helper functions will not be included.
%    
%    t   Translate M code to target language.  Translate any M-functions specified on
%        the command line to C or C++ functions.  This option is included in all
%        macro options.  Omitting it allows the generation of wrapper C/C++ files
%        without generating the C/C++ files corresponding to M-files.
%    
%    T <option> Specify target phase.  <option> must be "codegen",
%        "compile:<bintype>", "link:<bintype>", or "lib:<bintype>", where <bintype>
%        must be one of "mex", "exe", or "lib".  If <option> is "codegen", the
%        Compiler stops after performing M-to-C/C++ translation and wrapper file
%        generation.  If <option> starts with "compile:", the Compiler performs the
%        previous step and then compiles the C/C++ file(s) into object file(s).  The
%        built object file(s) are suitable for linking into a MEX-file if <bintype>
%        is "mex", into a stand-alone application if <bintype> is "exe", or into a
%        shared library if <bintype> is "lib".  If <option> begins with "link:", the
%        Compiler performs both previous steps and then links the object code into a
%        MEX-file (if <bintype> is "mex"), a stand-alone application (if <bintype> is
%        "exe"), or a shared library (if <bintype> is "lib").
%    
%    u <number> Specify that the number of inputs to a generated Simulink S-function
%        should be <number>.  Valid only if either "-S" or "-W simulink" option has
%        also been specified.
%    
%    v   Verbose.  Show compilation steps.
%    
%    V1.2 Access Compiler 1.2.1. The options described in this text are for Compiler
%        2.0 only. Type "mcc -V1.2 -?" to obtain the online help for Compiler 1.2.1.
%    
%    w list.  List the <msg> strings allowed in the next form of the command,
%        together with the full text of the warning messages to which they
%        correspond.
%    
%    w <option>[:<msg>] Warnings.  The possible options are "enable", "disable", and
%        "error".  If "enable:<msg>" or "disable:<msg>" is specified, enable or
%        disable the warning associated with <msg>.  If "error:<msg>" is specified,
%        enable the warning associated with <msg> and treat any instances of that
%        warning as an error.  If the <option> but not ":<msg>" is specified, the
%        Compiler applies the action to all warning messages.  For compatibility with
%        Compiler 1.2, "-w" (with no option) is the same as "-w enable".
%    
%    W <option> Wrapper functions.  Specify which type of wrapper file should be
%        generated by the Compiler.  <option> can be one of "mex", "main",
%        "simulink", "lib:<string>", or "none" (default).  For the lib wrapper,
%        <string> contains the name of the generated header, source and exports file.
%    
%    x   Macro that generates a MEX file.  This is equivalent to
%        "-t -W mex -L C -T link:mex".  Note:  the absence of "-h" means that helper
%        functions will not be included.
%    
%    y <number> Specify that the number of outputs from a generated Simulink
%        S-function should be <number>.  Valid only if either "-S" or "-W simulink"
%        option has also been specified.
%    
%    Y <license.dat file> Override default license.dat file with specified
%        argument.
%    
%    z <path>  Specify the path to use for library and include files.
%        This option uses the specified path for the Compiler libraries
%        instead of MATLABROOT.
%    
%    ?   Help.  Display this help message.
%    
%    EXAMPLES:
%    
%    Make a C translation and a MEX-file for myfun.m:
%        mcc -x myfun
%    
%    Make a C translation and a stand-alone executable for myfun.m:
%        mcc -m myfun
%    
%    Make a C++ translation and a stand-alone executable for myfun.m:
%        mcc -p myfun
%    
%    Make a C translation and a Simulink S-function for myfun.m
%     (using dynamically sized inputs and outputs):
%        mcc -S myfun
%    
%    Make a C translation and a Simulink S-function for myfun.m
%     (explicitly calling for one input and two outputs):
%        mcc -S -u 1 -y 2 myfun
%    
%    Make a C translation and stand-alone executable for myfun.m.  Look for
%     myfun.m in the directory /files/source, and put the resulting C files and
%     executable in the directory /files/target:
%        mcc -m -I /files/source -d /files/target myfun
%    
%    Make a C translation and a MEX-file for myfun.m.  Also translate and include 
%     all M-functions called directly or indirectly by myfun.m.  Incorporate the 
%     full text of the original M-files into their corresponding C files as C 
%     comments:
%        mcc -x -h -A annotation:all myfun
%    
%    Make a generic C translation of myfun.m:
%        mcc -t -L C myfun
%    
%    Make a generic C++ translation of myfun.m:
%        mcc -t -L Cpp myfun
%    
%    Make a C MEX wrapper file from myfun1.m and myfun2.m:
%        mcc -W mex -L C myfun1 myfun2
%    
%    Make a C translation and a stand-alone executable from myfun1.m and myfun2.m
%     (using one mcc call):
%        mcc -m myfun1 myfun2
%    
%    Make a C translation and a stand-alone executable from myfun1.m and myfun2.m
%     (by generating each output file with a separate mcc call):
%        mcc -t -L C myfun1                 % yields myfun1.c
%        mcc -t -L C myfun2                 % yields myfun2.c
%        mcc -W main -L C myfun1 myfun2     % yields myfun1_main.c
%        mcc -T compile:exe myfun1.c        % yields myfun1.o
%        mcc -T compile:exe myfun2.c        % yields myfun2.o
%        mcc -T compile:exe myfun1_main.c   % yields myfun1_main.o
%        mcc -T link:exe myfun1.o myfun2.o myfun1_main.o
%    
%     Note: on PCs, filenames ending with .o above would actually end with .obj.
% 
% 
%    

function mbuild
%MATLAB Tour Partial Function Help:  comp_con
%
% MBUILD Compile an executable from C source code.
%    MBUILD <options> <files> compiles an executable from C source code.
%    All non-source code file names passed as arguments are passed to the
%    linker without being compiled.
% 
%    Available options on all platforms are:
%    -c               Compile only; do not link.
%    -D<name>[=<def>] Define C preprocessor macro name <name> [as having value
%                     <def> (assignment not available under Windows)].
%    -f <file>        Use <file> as the options file; <file> is a full path
%                     name if not in current directory. (Not necessary if you
%                     use the -setup option.)
%    -g               Build an executable with debugging symbols included.
%    -h[elp]          Help; print this message.
%    -I<pathname>     Include <pathname> in the Compiler include search path.
%    -lang <language> Override language choice implied by file extensions.
%                     <language> is either 'c' (for C) or 'cpp' (for C++).
%    -n               No execute flag. Using this option causes the commands
%                     that would be used to compile and link the target to be
%                     displayed without executing them.
%    -O               Build an optimized executable.
%    -output <name>   Create an executable named <name>. (An appropriate
%                     executable extension is automatically appended.)
%    -outdir <name>   Place all output files in directory <name>
%    -setup [optionsfile]
%                     Specify the Compiler options file to use as the
%                     default for future invocations of mbuild by
%                     placing it in $HOME/matlab. When this option is specified,
%                     no other command line input is accepted.
%    -U<name>         Undefine C preprocessor macro name <name>.
%    -v               Verbose; print all Compiler and linker settings.
% 
%    On UNIX, the following additional options are available:
%    -l<file>         Link against library lib<file>.
%    -L<pathname>     Include <pathname> in the list of directories to search
%                     for libraries.
%    <name>=<def>     Override options file setting for variable <name>.
% 
%    On Windows, the following additional options are available:
%    @<rsp_file>      Include contents of the text file <rsp_file> as
%                     command line arguments to MBUILD
% 
%    MBUILD's execution is affected by both command-line arguments and
%    an options file.  The options file contains all Compiler-specific
%    information necessary to create an executable.  The name of this file
%    must be specified.
% 
%    On UNIX, the options file is written in the Bourne shell script language.
%    Any variable specified in the options file can be overridden at the command
%    line by use of the <name>=<def> command line argument.  If <def> has
%    spaces in it, then it should be wrapped in single quotes
%    (e.g. CFLAGS='opt1 opt2').  The definition can rely on other variables
%    defined in the options file; in this case the referenced variable should
%    have a prepended "$" (e.g. CFLAGS='$CFLAGS opt2').
% 
%    On Windows, the options file is written in the Perl script
%    language. No arguments can have an embedded equal sign ("="); thus,
% 
%       -DFOO     is valid, but
%       -DFOO=BAR is not.

function mbint
%MATLAB Tour Partial Function Help:  comp_con
%
% MBINT   Must be integer.
%    The statement
% 
%        mbint(x)
% 
%    asserts that, at that point in the computation, the variable x 
%    has components which can be declared type "int" in the resulting
%    C program.  If this assertion is false, an error occurs; if this
%    assertion is true, the computation proceeds.
% 
%    

function mbreal
%MATLAB Tour Partial Function Help:  comp_con
%
% MBREAL   Must be real.
%    The statement
% 
%        mbreal(x)
% 
%    asserts that, at that point in the computation, the imaginary part
%    of variable x is zero.  If this assertion is false, an error occurs;
%    if this assertion is true, the computation proceeds.
% 
%    

function mbchar
%MATLAB Tour Partial Function Help:  comp_con
%
% MBCHAR	Must be char variable.
% 	The statement
% 
% 	    mbchar(x)
% 
% 	asserts that, at that point in the computation, the variable x 
% 	has components can be declared as char strings in the resulting
% 	C program.  If this assertion is false, an error occurs; if this
% 	assertion is true, the computation proceeds.
% 
% 	

function mbscalar
%MATLAB Tour Partial Function Help:  comp_con
%
% MBSCALAR Must be scalar.
%    The statement
% 
%        mbscalar(x)
% 
%    asserts that, at that point in the computation, the variable x 
%    has size 1-by-1.  If this assertion is false, an error occurs;
%    if this assertion is true, the computation proceeds.
% 
%    

function mbvector
%MATLAB Tour Partial Function Help:  comp_con
%
% MBVECTOR Must be vector.
%    The statement
% 
%        mbvector(x)
% 
%    asserts that, at that point in the computation, the variable x has
%    size m-by-1 or 1-by-n.  If this assertion is false, an error occurs;
%    if this assertion is true, the computation proceeds.
% 
%    

function mbintscalar
%MATLAB Tour Partial Function Help:  comp_con
%
% MBINTSCALAR Must be integer scalar.
%    The statement
% 
%        mbintscalar(x)
% 
%    is equivalent to
% 
%        mbint(x) ; mbscalar(x) ;
% 
%    

function mbintvector
%MATLAB Tour Partial Function Help:  comp_con
%
% MBINTVECTOR Must be integer vector.
%    The statement
% 
%        mbintvector(x)
% 
%    is equivalent to
% 
%        mbint(x) ; mbvector(x) ;
% 
%    

function mbrealscalar
%MATLAB Tour Partial Function Help:  comp_con
%
% MBREALSCALAR Must be real scalar.
%    The statement
% 
%        mbrealscalar(x)
% 
%    is equivalent to
% 
%        mbreal(x) ; mbscalar(x) ;
% 
%    

function mbrealvector
%MATLAB Tour Partial Function Help:  comp_con
%
% MBREALVECTOR Must be real vector.
%    The statement
% 
%        mbrealvector(x)
% 
%    is equivalent to
% 
%        mbreal(x) ; mbvector(x) ;
% 
%    

function mbcharvector
%MATLAB Tour Partial Function Help:  comp_con
%
% MBCHARVECTOR	Must be vector char variable
% 
% 	The statement
% 
% 	    mbcharvector(x)
% 
%        is equivalent to
% 
%            mbchar(x) ; mbvector(x) ;
% 
% 	

function mbcharscalar
%MATLAB Tour Partial Function Help:  comp_con
%
% MBCHARSCALAR	Must be scalar char variable
% 
% 	The statement
% 
% 	    mbcharscalar(x)
% 
%        is equivalent to
% 
%            mbchar(x) ; mbscalar(x) ;
% 
% 	

function reallog
%MATLAB Tour Partial Function Help:  comp_con
%
% REALLOG Real logarithm.
%    REALLOG(X) requires X to have real, nonnegative elements.
% 
%    

function realpow
%MATLAB Tour Partial Function Help:  comp_con
%
% REALPOW Real power.
%    REALPOW(X,Y) requires X.^Y to be real.
% 
%    

function realsqrt
%MATLAB Tour Partial Function Help:  comp_con
%
% REALSQRT Real square root.
%    REALSQRT(X) requires X to have real, nonnegative elements.
% 
%    

function inbounds
%MATLAB Tour Partial Function Help:  comp_con
%
% INBOUNDS MATLAB Compiler pragma.
%    The statement
%       %#inbounds
%    may appear anywhere in an M-file defining a function.
%    Since it begins with a % sign, it is taken to be a comment by the
%    MATLAB interpreter.  But, to the MATLAB Compiler, MCC, it is an
%    indication to eliminate input argument and subscript checking in
%    the resulting C code.  It is necessary to use ZEROS, or some other
%    function, to create an array before referencing individual elements.
%    Runtime subscripting errors may cause memory protection faults.
%    This pragma is equivalent to the -i option on the MCC command.
% 
%    

function realonly
%MATLAB Tour Partial Function Help:  comp_con
%
% REALONLY MATLAB Compiler pragma.
%    The statement
%       %#realonly
%    may appear anywhere in an M-file defining a function.
%    Since it begins with a % sign, it is taken to be a comment by the
%    MATLAB interpreter.  But, to the MATLAB Compiler, MCC, it is an
%    indication that the entire function involves only real arithmetic.
%    All input arguments must be real, and all computations within the
%    function, including all square roots, logarithms and powers, must
%    produce real results.
%    This pragma is equivalent to the -r option on the MCC command.
% 
%    

function ivdep
%MATLAB Tour Partial Function Help:  comp_con
%
% IVDEP MATLAB Compiler pragma.
%    The statement
%       %#ivdep
%    may appear just before any FOR loop in an M-file defining a function.
%    Since it begins with a % sign, it is taken to be a comment by the
%    MATLAB interpreter.  But, to the MATLAB Compiler, MCC, it is an
%    indication to "ignore vector dependencies" in the FOR loop.
%    In principle, the computations in the loop can be done in any order,
%    or all done simultaneously.  This allows the Compiler to generate
%    faster, "vectorized", code.
%    There is no equivalent option for the MCC command.
% 
%    

function function
%MATLAB Tour Partial Function Help:  comp_con
%
% FUNCTION Add new function.
%    New functions may be added to MATLAB's vocabulary if they
%    are expressed in terms of other existing functions. The 
%    commands and functions that comprise the new function must
%    be put in a file whose name defines the name of the new 
%    function, with a filename extension of '.m'. At the top of
%    the file must be a line that contains the syntax definition
%    for the new function. For example, the existence of a file 
%    on disk called STAT.M with:
%  
%            function [mean,stdev] = stat(x)
%            %STAT Interesting statistics.
%            n = length(x);
%            mean = sum(x) / n;
%            stdev = sqrt(sum((x - mean).^2)/n);
%  
%    defines a new function called STAT that calculates the 
%    mean and standard deviation of a vector. The variables
%    within the body of the function are all local variables.
%    See SCRIPT for procedures that work globally on the work-
%    space. 
% 
%    A subfunction that is visible to the other functions in the
%    same file is created by defining a new function with the FUNCTION
%    keyword after the body of the preceding function or subfunction.
%    For example, avg is a subfunction within the file STAT.M:
% 
%           function [mean,stdev] = stat(x)
%           %STAT Interesting statistics.
%           n = length(x);
%           mean = avg(x,n);
%           stdev = sqrt(sum((x-avg(x,n)).^2)/n);
% 
%           %-------------------------
%           function mean = avg(x,n)
%           %MEAN subfunction
%           mean = sum(x)/n;
% 
%    Subfunctions are not visible outside the file where they are defined.
%    Normally functions return when the end of the function is reached.
%    A RETURN statement can be used to force an early return.
% 
%    

